@@ -57,13 +57,15 @@ class Util:
                 print("checking columns: ", x, " | ", solution[x])
                 for y in range(len(solution[x])):
                     print("   checking cell:", y, " | ", solution[x][y])
-                    check = _levenshtein.ratio(solution[x][y], student_dict[x][y])
+                    check = Util.levenshtein_str_callback(solution[x][y], student_dict[x][y])
                     if 0.8 <= check:
                         score += partial_score_exact
                     print("    > ", check, ", score: ", round(score, 4))
         except Exception as e:
             print('exception caught, aborting')
-            print(e)
+            print(f'  {type(e).__name__} {e} ')
+            if type(e).__name__ == "KeyError":
+                print("  ... this error message likely means that a column name is misspelled or that a column was not found.")
             pass  # catch, return
         else:
             # if the solution isn't exact, apply other rules
